﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using System.Collections.Generic;

namespace NorthArrowDemo
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;

            InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
            inMemoryLayer.Columns.Add(new FeatureSourceColumn("TextAngle"));
            inMemoryLayer.Columns.Add(new FeatureSourceColumn("Text"));
            inMemoryLayer.Columns.Add(new FeatureSourceColumn("ImageAngle"));
            inMemoryLayer.Columns.Add(new FeatureSourceColumn("Image"));
            inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            inMemoryLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(new RotatePointStyle());

            Feature feature1 = new Feature(new PointShape(0, 0));
            feature1.ColumnValues.Add("Text", "Vahicle1");
            feature1.ColumnValues.Add("TextAngle", "0");
            feature1.ColumnValues.Add("ImageAngle", "0");
            feature1.ColumnValues.Add("Image", @"..\..\Car.png");
            inMemoryLayer.InternalFeatures.Add(feature1);

            Feature feature2 = new Feature(new PointShape(104, 30));
            feature2.ColumnValues.Add("Text", "Vahicle2");
            feature2.ColumnValues.Add("TextAngle", "-15");
            feature2.ColumnValues.Add("ImageAngle", "45");
            feature2.ColumnValues.Add("Image", @"..\..\Car.png");
            inMemoryLayer.InternalFeatures.Add(feature2);

            winformsMap1.DynamicOverlay.Layers.Add(inMemoryLayer);

            winformsMap1.Refresh();
        }

        public class RotatePointStyle : PointStyle
        {
            public RotatePointStyle()
                : base()
            { }

            protected override Collection<string> GetRequiredColumnNamesCore()
            {
                Collection<string> columns = new Collection<string>();
                columns.Add("Text");
                columns.Add("TextAngle");
                columns.Add("ImageAngle");
                columns.Add("Image");

                return columns;
            }

            protected override void DrawCore(IEnumerable<Feature> features, GeoCanvas canvas, Collection<SimpleCandidate> labelsInThisLayer, Collection<SimpleCandidate> labelsInAllLayers)
            {
                foreach (Feature feature in features)
                {
                    int imageAngle = Convert.ToInt32(feature.ColumnValues["ImageAngle"]);
                    int textAngle = Convert.ToInt32(feature.ColumnValues["TextAngle"]);
                    string text = feature.ColumnValues["Text"];
                    string imagePath = feature.ColumnValues["Image"];

                    PointShape location = (PointShape)feature.GetShape();
                    canvas.DrawWorldImageWithoutScaling(new GeoImage(imagePath), location.X, location.Y, DrawingLevel.LevelThree, 0, 0, imageAngle);

                    ScreenPointF locationInScreen = ExtentHelper.ToScreenCoordinate(canvas.CurrentWorldExtent, location, canvas.Width, canvas.Height);
                    Collection<ScreenPointF> textPathInScreen = new Collection<ScreenPointF> { locationInScreen };
                    GeoFont font = new GeoFont("Arial", 10); // You can specify the font you want here.
                    canvas.DrawText(text, font, new GeoSolidBrush(GeoColor.SimpleColors.Black), new GeoPen(), textPathInScreen, DrawingLevel.LevelFour, 0, -15, textAngle);
                }
            }
        }


    }
}
